import type { EquStatuVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  equStatuExport = '/eims/equStatu/export',
  equStatuList = '/eims/equStatu/list',
  root = '/eims/equStatu'
}

/**
 * 查询设备状态记录列表
 * @param query
 * @returns {*}
 */

export function listEquStatu(params?: any) {
  return requestClient.get<EquStatuVO[]>(Api.equStatuList, { params });
}

/**
 * 查询设备状态记录详细
 * @param statuId
 */
export function getEquStatu(statuId: ID) {
  return requestClient.get<EquStatuVO>(`${Api.root}/${statuId}`);
}

/**
 * 新增设备状态记录
 * @param data
 */
export function addEquStatu(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改设备状态记录
 * @param data
 */
export function updateEquStatu(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除设备状态记录
 * @param statuId
 */
export function delEquStatu(statuId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${statuId}`);
}
/**
 * 导出
 * @param
 */
export function equStatuExport(data: any) {
  return commonExport(Api.equStatuExport, data);
}
